OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Mensaje incrustado %s",
    "Important mail" : "Correo importante",
    "No message found yet" : "Aún no se encontraron mensajes",
    "Set up an account" : "Configurar una cuenta",
    "Unread mail" : "Correo no leído",
    "Important" : "Importante",
    "Work" : "Trabajo",
    "Personal" : "Personal",
    "To Do" : "Por hacer",
    "Later" : "Después",
    "Mail" : "Correo",
    "Mails" : "Correos",
    "💌 A mail app for Nextcloud" : "💌 Una aplicación de correo para Nextcloud",
    "Your session has expired. The page will be reloaded." : "Tu sesión ha expirado. La página se recargará.",
    "Drafts are saved in:" : "Los borradores se guardan en:",
    "Sent messages are saved in:" : "Los mensajes enviados se guardan en:",
    "Deleted messages are moved in:" : "Los mensajes eliminados se mueven a:",
    "Archived messages are moved in:" : "Los mensajes archivados se mueven a:",
    "Auto" : "Automático",
    "Name" : "Nombre",
    "Mail address" : "Dirección de correo",
    "name@example.org" : "nombre@example.org",
    "Please enter an email of the format name@example.com" : "Ingresa un correo electrónico en el formato nombre@example.com",
    "Password" : "Contraseña",
    "Manual" : "Manual",
    "IMAP Settings" : "Configuración IMAP",
    "IMAP Host" : "Servidor IMAP",
    "IMAP Security" : "Seguridad IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Settings" : "Configuración SMTP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Security" : "Seguridad SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Para que la cuenta de Google funcione con esta aplicación, debes habilitar la autenticación en dos pasos para Google y generar una contraseña de aplicación.",
    "Connecting" : "Conectando",
    "Reconnect Google account" : "Reconectar cuenta de Google",
    "Sign in with Google" : "Iniciar sesión con Google",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Looking up configuration" : "Buscando configuración",
    "Checking mail host connectivity" : "Comprobando la conectividad del host de correo",
    "Configuration discovery failed. Please use the manual settings" : "Error en el descubrimiento de la configuración. Por favor, usa la configuración manual",
    "Password required" : "Se requiere contraseña",
    "Testing authentication" : "Probando la autenticación",
    "Awaiting user consent" : "Esperando el consentimiento del usuario",
    "Loading account" : "Cargando cuenta",
    "Account updated" : "Cuenta actualizada",
    "IMAP server is not reachable" : "El servidor IMAP no es alcanzable",
    "SMTP server is not reachable" : "El servidor SMTP no es alcanzable",
    "IMAP username or password is wrong" : "El nombre de usuario o la contraseña IMAP son incorrectos",
    "SMTP username or password is wrong" : "El nombre de usuario o la contraseña SMTP son incorrectos",
    "IMAP connection failed" : "Falló la conexión IMAP",
    "SMTP connection failed" : "Falló la conexión SMTP",
    "Authorization pop-up closed" : "Se cerró el pop-up de autorización",
    "There was an error while setting up your account" : "Hubo un error al configurar tu cuenta",
    "Account settings" : "Configuración de la cuenta",
    "Aliases" : "Aliases",
    "Alias to S/MIME certificate mapping" : "Asignación de alias a certificados S/MIME",
    "Signature" : "Firma",
    "A signature is added to the text of new messages and replies." : "Se agrega una firma al texto de nuevos mensajes y respuestas.",
    "Writing mode" : "Modo de escritura",
    "Preferred writing mode for new messages and replies." : "Modo de escritura preferido para nuevos mensajes y respuestas.",
    "Default folders" : "Carpetas predeterminadas",
    "Autoresponder" : "Contestador automático",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Respuesta automática a mensajes entrantes. Si alguien te envía varios mensajes, esta respuesta automática se enviará como máximo una vez cada 4 días.",
    "Please connect to a sieve server first." : "Por favor, conecta primero con un servidor sieve.",
    "Filters" : "Filtros",
    "Mail server" : "Servidor de correo",
    "Update alias" : "Actualizar alias",
    "Rename alias" : "Renombrar alias",
    "Show update alias form" : "Mostrar formulario de actualización de alias",
    "Delete alias" : "Eliminar alias",
    "Go back" : "Regresar",
    "Change name" : "Cambiar nombre",
    "Email address" : "Dirección de correo electrónico",
    "Add alias" : "Agregar alias",
    "Create alias" : "Crear alias",
    "Cancel" : "Cancelar",
    "Mail settings" : "Configuración de correo",
    "Accounts" : "Cuentas",
    "Add mail account" : "Agregar cuenta de correo",
    "General" : "General",
    "Sorting" : "Ordenar",
    "Newest" : "Más recientes",
    "Oldest" : "Más antiguos",
    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
    "Register as application for mail links" : "Registrarse como aplicación para enlaces de correo",
    "Register" : "Registrar",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
    "Trusted senders" : "Remitentes de confianza",
    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
    "Looking for a way to encrypt your emails?" : "¿Buscas una forma de cifrar tus correos electrónicos?",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Compose new message" : "Escribir mensaje nuevo",
    "Newer message" : "Mensaje más nuevo",
    "Older message" : "Mensaje más antiguo",
    "Toggle star" : "Alternar favoritos",
    "Toggle unread" : "Alternar no leídos",
    "Archive" : "Archivar",
    "Delete" : "Borrar",
    "Search" : "Buscar",
    "Send" : "Enviar",
    "Refresh" : "Actualizar",
    "Put my text to the bottom of a reply instead of on top of it." : "Colocar mi texto en la parte inferior de una respuesta en lugar de en la parte superior.",
    "Could not update preference" : "No se pudo actualizar la preferencia",
    "Select an alias" : "Seleccionar un alias",
    "Update Certificate" : "Actualizar certificado",
    "No certificate" : "Sin certificado",
    "Certificate updated" : "Certificado actualizado",
    "Could not update certificate" : "No se pudo actualizar el certificado",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Válido hasta {expiryDate}",
    "From" : "De",
    "Select account" : "Selecciona la cuenta",
    "To" : "A",
    "Contact or email address …" : "Contacto o dirección de correo electrónico...",
    "Cc" : "Cc",
    "Bcc" : "Cco",
    "Subject" : "Asunto",
    "Subject …" : "Asunto...",
    "This message came from a noreply address so your reply will probably not be read." : "Este mensaje proviene de una dirección \"noreply\", por lo que probablemente no se lea tu respuesta.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Los siguientes destinatarios no tienen un certificado S/MIME: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Los siguientes destinatarios no tienen una clave PGP: {recipients}.",
    "Write message …" : "Escribir mensaje...",
    "Saving draft …" : "Guardando borrador...",
    "Error saving draft" : "Error al guardar el borrador",
    "Draft saved" : "Borrador guardado",
    "Save draft" : "Guardar borrador",
    "Discard & close draft" : "Descartar y cerrar borrador",
    "Enable formatting" : "Activar formato",
    "Disable formatting" : "Desactivar formato",
    "Upload attachment" : "Cargar adjunto",
    "Add attachment from Files" : "Agregar adjunto desd Archivos",
    "Smart picker" : "Selector inteligente",
    "Send later" : "Enviar más tarde",
    "Request a read receipt" : "Solicitar confirmación de lectura",
    "Sign message with S/MIME" : "Firmar mensaje con S/MIME",
    "Encrypt message with S/MIME" : "Cifrar mensaje con S/MIME",
    "Encrypt message with Mailvelope" : "Cifrar mensaje con Mailvelope",
    "Send now" : "Enviar ahora",
    "Tomorrow morning" : "Mañana por la mañana",
    "Tomorrow afternoon" : "Mañana por la tarde",
    "Monday morning" : "Lunes por la mañana",
    "Custom date and time" : "Fecha y hora personalizada",
    "Enter a date" : "Ingresa una fecha",
    "Encrypt with S/MIME and send later" : "Cifrar con S/MIME y enviar más tarde",
    "Encrypt with S/MIME and send" : "Cifrar con S/MIME y enviar",
    "Encrypt with Mailvelope and send later" : "Cifrar con Mailvelope y enviar más tarde",
    "Encrypt with Mailvelope and send" : "Cifrar con Mailvelope y enviar",
    "Message {id} could not be found" : "No se pudo encontrar el mensaje {id}",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Se seleccionó Firmar o Cifrar con S/MIME, pero no tenemos un certificado para el alias seleccionado. El mensaje no será firmado ni cifrado.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Cualquier formato existente (por ejemplo, negrita, cursiva, subrayado o imágenes en línea) se eliminará.",
    "Turn off formatting" : "Desactivar formato",
    "Turn off and remove formatting" : "Desactivar y eliminar formato",
    "Keep formatting" : "Conservar formato",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Choose a file to share as a link" : "Elige un archivo para compartir como enlace",
    "Choose" : "Seleccionar",
    "_{count} attachment_::_{count} attachments_" : ["{count} adjunto","{count} adjuntos","{count} adjuntos"],
    "Expand composer" : "Expandir redactor",
    "Close composer" : "Cerrar redactor",
    "Untitled message" : "Mensaje sin título",
    "Confirm" : "Confirmar",
    "Plain text" : "Texto sin formato",
    "Rich text" : "Texto enriquecido",
    "No messages in this mailbox" : "No hay mensajes en esta bandeja de entrada",
    "No messages" : "Sin mensajes",
    "Draft: " : "Borrador: ",
    "Encrypted message" : "Mensaje cifrado",
    "This message is unread" : "Este mensaje no se ha leído",
    "Unfavorite" : "Quitar favorito",
    "Favorite" : "Hacer favorito",
    "Unread" : "No leído",
    "Read" : "Leer",
    "Unimportant" : "No importante",
    "Mark not spam" : "Marcar como no spam",
    "Mark as spam" : "Marcar como spam",
    "Edit tags" : "Editar etiquetas",
    "Move thread" : "Mover hilo",
    "Archive thread" : "Archivar hilo",
    "Delete thread" : "Eliminar hilo",
    "More actions" : "Más acciones",
    "Back" : "Atrás",
    "Edit as new message" : "Editar como nuevo mensaje",
    "Create event" : "Crear evento",
    "Create task" : "Crear tarea",
    "Download message" : "Descargar mensaje",
    "Blind copy recipients only" : "Copias ocultas para los destinatarios solamente",
    "No subject" : "Sin asunto",
    "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
    "Could not delete message" : "No se pudo eliminar el mensaje",
    "Could not archive message" : "No se pudo archivar el mensaje",
    "Load more" : "Cargar más",
    "_Mark {number} read_::_Mark {number} read_" : ["Marcar {number} como leído","Marcar {number} como leído","Marcar {number} como leído"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Marcar {number} como no leído","Marcar {number} como no leído","Marcar {number} como no leído"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Marcar {number} como importante","Marcar {number} como importante","Marcar {number} como importante"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Marcar {number} como no importante","Marcar {number} como no importante","Marcar {number} como no importante"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["No marcar {number} como favorito","No marcar {number} como favorito","No marcar {number} como favorito"],
    "_Favorite {number}_::_Favorite {number}_" : ["Marcar {number} como favorito","Marcar {number} como favorito","Marcar {number} como favorito"],
    "_Unselect {number}_::_Unselect {number}_" : ["No seleccionar {number}","No seleccionar {number}","No seleccionar {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Mover {number} hilo","Mover {number} hilos","Mover {number} hilos"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Reenviar {number} como adjunto","Reenviar {number} como adjunto","Reenviar {number} como adjunto"],
    "Report this bug" : "Informar de este error",
    "All day" : "Todo el día",
    "Select calendar" : "Seleccionar calendario",
    "Description" : "Descripción",
    "Create" : "Crear",
    "Event created" : "Evento creado",
    "Could not create event" : "No se pudo crear el evento",
    "You accepted this invitation" : "Aceptaste esta invitación",
    "You tentatively accepted this invitation" : "Aceptaste tentativamente esta invitación",
    "You declined this invitation" : "Declinaste esta invitación",
    "You already reacted to this invitation" : "Ya has reaccionado a esta invitación",
    "You have been invited to an event" : "Has sido invitado a un evento",
    "This event was cancelled" : "Este evento fue cancelado",
    "Save to" : "Guardar en",
    "Select" : "Seleccionar",
    "Comment" : "Comentario",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentatively accept" : "Aceptar tentativamente",
    "More options" : "Más opciones",
    "This event is in the past." : "Este evento está en el pasado.",
    "This event was updated" : "Este evento ha sido actualizado",
    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó tu invitación",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó tentativamente tu invitación",
    "{attendeeName} declined your invitation" : "{attendeeName} rechazó tu invitación",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reaccionó a tu invitación",
    "Failed to save your participation status" : "Error al guardar tu estado de participación",
    "domain" : "dominio",
    "Remove" : "Eliminar",
    "email" : "correo electrónico",
    "individual" : "individual",
    "Itinerary for {type} is not supported yet" : "El itinerario de {type} aún no es compatible",
    "Could not open mailbox" : "No se pudo abrir el buzón",
    "Loading messages …" : "Cargando mensajes...",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indexando tus mensajes. Esto puede llevar un poco más de tiempo para buzones más grandes.",
    "To archive a message please configure an archive mailbox in account settings" : "Para archivar un mensaje, configura un buzón de archivo en la configuración de la cuenta",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "No tienes permiso para mover este mensaje al buzón de archivos y/o eliminar este mensaje de la carpeta actual",
    "Choose target mailbox" : "Selecciona el buzón de destino",
    "No more submailboxes in here" : "No hay más sub-buzones aquí",
    "Important info" : "Información importante",
    "Other" : "Otro",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Los mensajes se marcarán automáticamente como importantes en función de los mensajes con los que interactúes o que marques como importantes. Al principio, es posible que debas cambiar manualmente la importancia para enseñar al sistema, pero mejorará con el tiempo.",
    "The sender of this message has asked to be notified when you read this message." : "El remitente de este mensaje ha solicitado que se le notifique cuando leas este mensaje.",
    "Notify the sender" : "Notificar al remitente",
    "You sent a read confirmation to the sender of this message." : "Enviaste una confirmación de lectura al remitente de este mensaje.",
    "Could not send mdn" : "No se pudo enviar la notificación de lectura",
    "Forward" : "Adelante",
    "Move message" : "Mover mensaje",
    "Translate" : "Traducir",
    "Forward message as attachment" : "Reenviar mensaje como adjunto",
    "View source" : "Ver origen",
    "Download thread data for debugging" : "Descargar datos del hilo para depuración",
    "Message body" : "Cuerpo del mensaje",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Advertencia: La firma S/MIME de este mensaje no se ha verificado. ¡Es posible que el remitente esté haciéndose pasar por alguien!",
    "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Unnamed" : "Sin nombre",
    "Embedded message" : "Mensaje incrustado",
    "calendar imported" : "calendario importado",
    "View fewer attachments" : "Ver menos adjuntos",
    "Choose a folder to store the attachments in" : "Selecciona una carpeta para almacenar los adjuntos",
    "Save all to Files" : "Guardar todo a Archivos",
    "Download Zip" : "Descargar Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Ver {count} adjunto más","Ver {count} adjuntos más","Ver {count} adjuntos más"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Este mensaje está cifrado con PGP. Instala Mailvelope para descifrarlo.",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
    "Show images" : "Mostrar imágenes",
    "Show images temporarily" : "Mostrar imágenes temporalmente",
    "Always show images from {sender}" : "Mostrar siempre imágenes de {sender}",
    "Always show images from {domain}" : "Mostrar siempre imágenes de {domain}",
    "Message frame" : "Marco del mensaje",
    "Quoted text" : "Texto citado",
    "Move" : "Mover",
    "Moving" : "Moviendo",
    "Moving thread" : "Moviendo hilo",
    "Moving message" : "Moviendo mensaje",
    "Provisioned account is disabled" : "La cuenta proporcionada está desactivada",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Inicia sesión usando una contraseña para habilitar esta cuenta. La sesión actual está utilizando autenticación sin contraseña, como SSO o WebAuthn.",
    "Quota" : "Cuota",
    "Show only subscribed mailboxes" : "Mostrar solo buzones suscritos",
    "Add mailbox" : "Agregar buzón",
    "Saving" : "Guardando",
    "Move up" : "Mover hacia arriba",
    "Move down" : "Mover hacia abajo",
    "Remove account" : "Eliminar cuenta",
    "Loading …" : "Loading …",
    "Not supported by the server" : "No es compatible con el servidor",
    "{usage} of {limit} used" : "{usage} de {limit} usado",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "La cuenta para {email} y los datos de correo en caché se eliminarán de Nextcloud, pero no de tu proveedor de correo electrónico.",
    "Remove {email}" : "Eliminar {email}",
    "Show all subscribed mailboxes" : "Mostrar todos los buzones suscritos",
    "Show all mailboxes" : "Mostrar todos los buzones",
    "Collapse mailboxes" : "Colapsar buzones",
    "Mark all as read" : "Marcar todos como leídos",
    "Mark all messages of this mailbox as read" : "Marcar todos los mensajes de este buzón como leídos",
    "Add submailbox" : "Agregar sub-buzón",
    "Rename" : "Renombrar",
    "Move mailbox" : "Mover buzón",
    "Clear cache" : "Borrar el caché",
    "Clear locally cached data, in case there are issues with synchronization." : "Borrar datos en caché local, en caso de problemas con la sincronización.",
    "Subscribed" : "Suscrito",
    "Sync in background" : "Sincronizar en segundo plano",
    "Clear mailbox" : "Limpiar buzón",
    "Delete mailbox" : "Eliminar buzón",
    "All messages in mailbox will be deleted." : "Se eliminarán todos los mensajes del buzón.",
    "Clear mailbox {name}" : "Limpiar buzón {name}",
    "The mailbox and all messages in it will be deleted." : "Se eliminará el buzón y todos los mensajes en él.",
    "Delete mailbox {name}" : "Eliminar buzón {name}",
    "An error occurred, unable to rename the mailbox." : "Se produjo un error, no se puede cambiar el nombre del buzón.",
    "_{total} message_::_{total} messages_" : ["{total} mensaje","{total} mensajes","{total} mensajes"],
    "Outbox" : "Bandeja de salida",
    "New message" : "Mensaje nuevo",
    "Error sending your message" : "Error al enviar tu mensaje",
    "Retry" : "Reintentar",
    "Uploading attachments …" : "Subiendo adjuntos...",
    "Sending …" : "Enviando ...",
    "Warning sending your message" : "Advertencia al enviar tu mensaje",
    "Send anyway" : "Enviar de todos modos",
    "Minimize composer" : "Minimizar editor",
    "Edit message" : "Editar mensaje",
    "Draft" : "Borrador",
    "Reply" : "Responder",
    "Message saved" : "Mensaje guardado",
    "Failed to save message" : "Error al guardar el mensaje",
    "Failed to save draft" : "Error al guardar el borrador",
    "No sent mailbox configured. Please pick one in the account settings." : "No hay un buzón de envío configurado. Por favor, elige uno en la configuración de la cuenta.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Estás intentando enviar a muchos destinatarios en Para y/o Cc. Considera usar Bcc para ocultar las direcciones de los destinatarios.",
    "Message discarded" : "Mensaje descartado",
    "Could not discard message" : "No se pudo descartar el mensaje",
    "Autoresponder off" : "Respuesta automática desactivada",
    "Autoresponder on" : "Respuesta automática activada",
    "First day" : "Primer día",
    "Last day (optional)" : "Último día (opcional)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} será reemplazado con el asunto del mensaje al que estás respondiendo",
    "Message" : "Mensaje",
    "Oh Snap!" : "¡Ups!",
    "Save autoresponder" : "Guardar respuesta automática",
    "Could not open outbox" : "No se pudo abrir la bandeja de salida",
    "Pending or not sent messages will show up here" : "Los mensajes pendientes o no enviados aparecerán aquí",
    "Message could not be sent" : "No se pudo enviar el mensaje",
    "Message deleted" : "Mensaje eliminado",
    "Contacts with this address" : "Contactos con esta dirección",
    "Add to Contact" : "Agregar a Contactos",
    "New Contact" : "Nuevo contacto",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Contact name …" : "Nombre del contacto ...",
    "Add" : "Agregar",
    "Copied email address to clipboard" : "Dirección de correo electrónico copiada al portapapeles",
    "Could not copy email address to clipboard" : "No se pudo copiar la dirección de correo electrónico al portapapeles",
    "Show less" : "Mostrar menos",
    "Show more" : "Mostrar más",
    "Search in mailbox" : "Buscar en el correo",
    "Close" : "Cerrar",
    "Search parameters" : "Parámetros de búsqueda",
    "Body" : "Cuerpo",
    "Date" : "Fecha",
    "Pick a start date" : "Elegir una fecha de inicio",
    "Pick an end date" : "Elegir una fecha de finalización",
    "Select senders" : "Seleccionar remitentes",
    "Select recipients" : "Seleccionar destinatarios",
    "Select CC recipients" : "Seleccionar destinatarios CC",
    "Select BCC recipients" : "Seleccionar destinatarios BCC",
    "Tags" : "Etiquetas",
    "Select tags" : "Selecciona las etiquetas",
    "Marked as" : "Marcado como",
    "Has attachments" : "Tiene archivos adjuntos",
    "Clear" : "Limpiar",
    "Sieve Port" : "Puerto Sieve",
    "Custom" : "Personalizado",
    "Sieve User" : "Usuario Sieve",
    "Sieve Password" : "Contraseña Sieve",
    "Save sieve settings" : "Guardar configuración de Sieve",
    "Save sieve script" : "Guardar script de Sieve",
    "The syntax seems to be incorrect:" : "La sintaxis parece ser incorrecta:",
    "Signature …" : "Firma ...",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Tu firma tiene un tamaño mayor de 2 MB. Esto puede afectar el rendimiento de tu editor.",
    "Save signature" : "Guardar firma",
    "Place signature above quoted text" : "Colocar firma sobre el texto citado",
    "Saving new tag name …" : "Guardando nuevo nombre de etiqueta ...",
    "Set tag" : "Establecer etiqueta",
    "Unset tag" : "Quitar etiqueta",
    "An error occurred, unable to rename the tag." : "Ocurrió un error, no se pudo cambiar el nombre de la etiqueta.",
    "Add default tags" : "Agregar etiquetas predeterminadas",
    "Add tag" : "Agregar etiqueta",
    "Saving tag …" : "Guardando etiqueta ...",
    "Tag name is a hidden system tag" : "El nombre de la etiqueta es una etiqueta oculta del sistema",
    "Tag already exists" : "La etiqueta ya existe",
    "An error occurred, unable to create the tag." : "Ocurrió un error, no se pudo crear la etiqueta.",
    "No calendars with task list support" : "No hay calendarios con soporte de lista de tareas",
    "Task created" : "Tarea creada",
    "Could not create task" : "No se pudo crear la tarea",
    "Loading thread" : "Cargando hilo",
    "Not found" : "No encontrado",
    "Could not load your message thread" : "No se pudo cargar el hilo de mensajes",
    "The thread doesn't exist or has been deleted" : "El hilo no existe o ha sido eliminado",
    "Unsubscribe" : "Cancelar suscripción",
    "Reply all" : "Responder a todos",
    "Reply to sender only" : "Responder solo al remitente",
    "Mark as unfavorite" : "Marcar como no favorito",
    "Mark as favorite" : "Marcar como favorito",
    "Mark as unread" : "Marcar como no leído",
    "Mark as read" : "Marcar como leído",
    "Archive message" : "Archivar mensaje",
    "Delete message" : "Eliminar mensaje",
    "Message source" : "Origen del mensaje",
    "Unsubscribe via link" : "Cancelar suscripción mediante enlace",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Cancelar la suscripción detendrá todos los mensajes de la lista de correo {sender}",
    "Send unsubscribe email" : "Enviar correo electrónico de cancelación de suscripción",
    "Unsubscribe via email" : "Cancelar suscripción por correo electrónico",
    "Encrypted & verified " : "Cifrado y verificado ",
    "Signature verified" : "Firma verificada",
    "Signature unverified " : "Firma no verificada ",
    "This message was encrypted by the sender before it was sent." : "Este mensaje fue cifrado por el remitente antes de enviarlo.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Este mensaje contiene una firma digital S/MIME verificada. El mensaje no ha sido modificado desde que fue enviado.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Este mensaje contiene una firma digital S/MIME no verificada. El mensaje podría haber sido modificado desde que fue enviado o el certificado del firmante no es confiable.",
    "Unsubscribe request sent" : "Solicitud de cancelación de suscripción enviada",
    "Could not unsubscribe from mailing list" : "No se pudo cancelar la suscripción a la lista de correo",
    "Translate message" : "Traducir mensaje",
    "Source language to translate from" : "Idioma de origen para traducir",
    "Translate from" : "Traducir desde",
    "Target language to translate into" : "Idioma de destino para la traducción",
    "Translate to" : "Traducir a",
    "Translating" : "Traduciendo",
    "Copy translated text" : "Copiar texto traducido",
    "The message could not be translated" : "No se pudo traducir el mensaje",
    "Translation copied to clipboard" : "Traducción copiada al portapapeles",
    "Translation could not be copied" : "No se pudo copiar la traducción",
    "No senders are trusted at the moment." : "No hay remitentes confiables en este momento.",
    "Could not remove trusted sender {sender}" : "No se pudo eliminar el remitente confiable {sender}",
    "(organizer)" : "(organizador)",
    "Untitled event" : "Evento sin título",
    "Import into {calendar}" : "Importar en {calendar}",
    "Event imported into {calendar}" : "Evento importado en {calendar}",
    "Airplane" : "Avión",
    "Reservation {id}" : "Reserva {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Vuelo {flightNr} desde {depAirport} a {arrAirport}",
    "Train" : "Tren",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} desde {depStation} a {arrStation}",
    "Train from {depStation} to {arrStation}" : "Tren desde {depStation} a {arrStation}",
    "Flag" : "Bandera",
    "Operator" : "Operador",
    "Actions" : "Acciones",
    "New action" : "Nueva acción",
    "Priority" : "Prioridad",
    "Mail app" : "Aplicación de correo",
    "The mail app allows users to read mails on their IMAP accounts." : "La aplicación de correo permite a los usuarios leer correos en sus cuentas IMAP.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Aquí puedes encontrar la configuración a nivel de instancia. La configuración específica del usuario se encuentra en la propia aplicación (esquina inferior izquierda).",
    "Account provisioning" : "Provisión de cuentas",
    "A provisioning configuration will provision all accounts with a matching email address." : "Una configuración de provisión aprovisionará todas las cuentas con una dirección de correo electrónico coincidente.",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "El uso del comodín (*) en el campo de dominio de provisión creará una configuración que se aplica a todos los usuarios, siempre y cuando no coincidan con otra configuración.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "El mecanismo de provisión priorizará las configuraciones de dominio específicas sobre la configuración de dominio comodín.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Si se encuentra una nueva configuración coincidente después de que el usuario ya haya sido aprovisionado con otra configuración, la nueva configuración tendrá prioridad y el usuario será aprovisionado nuevamente con la configuración.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "Solo puede haber una configuración por dominio y solo una configuración de dominio comodín.",
    "These settings can be used in conjunction with each other." : "Estos ajustes se pueden utilizar conjuntamente.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "Si solo deseas aprovisionar un dominio para todos los usuarios, utiliza el comodín (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Esta configuración solo tiene más sentido si utilizas el mismo back-end de usuario para tu Nextcloud y servidor de correo de tu organización.",
    "Provisioning Configurations" : "Configuraciones de provisión",
    "Add new config" : "Agregar nueva configuración",
    "Provision all accounts" : "Aprovisionar todas las cuentas",
    "Allow additional mail accounts" : "Permitir cuentas de correo adicionales",
    "Allow additional Mail accounts from User Settings" : "Permitir cuentas de correo adicionales desde la configuración del usuario",
    "Anti Spam Service" : "Servicio Anti Spam",
    "You can set up an anti spam service email address here." : "Aquí puedes configurar una dirección de correo electrónico para el servicio anti spam.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Cualquier correo electrónico que sea marcado como spam será enviado al servicio anti spam.",
    "Gmail integration" : "Integración con Gmail",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail permite a los usuarios acceder a su correo electrónico a través de IMAP. Por razones de seguridad, este acceso solo es posible con una conexión OAuth 2.0 o cuentas de Google que utilizan autenticación de dos factores y contraseñas de aplicaciones.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Debes registrar un nuevo ID de cliente para una \"aplicación web\" en la consola de Google Cloud. Agrega la URL {url} como URI de redirección autorizado.",
    "Microsoft integration" : "Integración con Microsoft",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft permite a los usuarios acceder a su correo electrónico a través de IMAP. Por razones de seguridad, este acceso solo es posible con una conexión OAuth 2.0.",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Debes registrar una nueva aplicación en el portal de Microsoft Azure Active Directory. Agrega la URL {url} como URI de redirección.",
    "Successfully updated config for \"{domain}\"" : "Configuración actualizada con éxito para \"{domain}\"",
    "Error saving config" : "Error al guardar la configuración",
    "Saved config for \"{domain}\"" : "Configuración guardada para \"{domain}\"",
    "Could not save provisioning setting" : "No se pudo guardar la configuración de aprovisionamiento",
    "There was an error when provisioning accounts." : "Se produjo un error al aprovisionar cuentas.",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Cuentas eliminadas y desaprovisionadas con éxito para \"{domain}\"",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Error al eliminar y desaprovisionar cuentas para \"{domain}\"",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Se aprovisionó con éxito {count} cuenta.","Se aprovisionaron con éxito {count} cuentas.","Se aprovisionaron con éxito {count} cuentas."],
    "Anti Spam" : "Anti Spam",
    "Add the email address of your anti spam report service here." : "Agrega la dirección de correo electrónico de tu servicio de informes anti spam aquí.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Cuando uses esta configuración, se enviará un correo electrónico de informe al servidor de informes SPAM cuando un usuario haga clic en \"Marcar como spam\".",
    "The original message will be attached as a \"message/rfc822\" attachment." : "El mensaje original se adjuntará como un archivo \"message/rfc822\".",
    "\"Mark as Spam\" Email Address" : "Dirección de correo electrónico para \"Marcar como Spam\"",
    "\"Mark Not Junk\" Email Address" : "Dirección de correo electrónico para \"Marcar como No Deseado\"",
    "Reset" : "Restablecer",
    "Successfully set up anti spam email addresses" : "Direcciones de correo electrónico para informes de spam configuradas con éxito",
    "Error saving anti spam email addresses" : "Error al guardar las direcciones de correo electrónico para informes de spam",
    "Successfully deleted anti spam reporting email" : "Correo electrónico de informe de spam eliminado correctamente",
    "Error deleting anti spam reporting email" : "Error al eliminar el correo electrónico de informe de spam",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "Unlink" : "Desvincular",
    "Google integration configured" : "Integración con Google configurada",
    "Could not configure Google integration" : "No se pudo configurar la integración con Google",
    "Google integration unlinked" : "Integración con Google desvinculada",
    "Could not unlink Google integration" : "No se pudo desvincular la integración con Google",
    "Tenant ID (optional)" : "ID de inquilino (opcional)",
    "Microsoft integration configured" : "Integración con Microsoft configurada",
    "Could not configure Microsoft integration" : "No se pudo configurar la integración con Microsoft",
    "Microsoft integration unlinked" : "Integración con Microsoft desvinculada",
    "Could not unlink Microsoft integration" : "No se pudo desvincular la integración con Microsoft",
    "Domain Match: {provisioningDomain}" : "Correspondencia de dominio: {provisioningDomain}",
    "Email: {email}" : "Correo electrónico: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} en {host}:{port} (cifrado {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} en {host}:{port} (cifrado {ssl})",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} en {host}:{port} (cifrado {ssl})",
    "Configuration for \"{provisioningDomain}\"" : "Configuración para \"{provisioningDomain}\"",
    "Provisioning domain" : "Dominio de aprovisionamiento",
    "Email address template" : "Plantilla de dirección de correo electrónico",
    "IMAP" : "IMAP",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Habilitar integración con Sieve",
    "LDAP aliases integration" : "Integración con alias LDAP",
    "Enable LDAP aliases integration" : "Habilitar integración con alias LDAP",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "La integración con alias LDAP lee un atributo del directorio LDAP configurado para aprovisionar alias de correo electrónico.",
    "LDAP attribute for aliases" : "Atributo LDAP para alias",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Atributo multivalor para aprovisionar alias de correo electrónico. Se crea un alias para cada valor. Los alias existentes en Nextcloud que no estén en el directorio LDAP se eliminarán.",
    "Save Config" : "Guardar configuración",
    "Unprovision & Delete Config" : "Desaprovisionar y eliminar configuración",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% y %EMAIL% se reemplazarán con el UID y el correo electrónico del usuario",
    "With the settings above, the app will create account settings in the following way:" : "Con la configuración anterior, la aplicación creará configuraciones de cuenta de la siguiente manera:",
    "S/MIME certificates" : "Certificados S/MIME",
    "Certificate name" : "Nombre del certificado",
    "E-mail address" : "Dirección de correo electrónico",
    "Valid until" : "Válido hasta",
    "Delete certificate" : "Eliminar certificado",
    "No certificate imported yet" : "Aún no se ha importado ningún certificado",
    "Import certificate" : "Importar certificado",
    "Import S/MIME certificate" : "Importar certificado S/MIME",
    "PKCS #12 Certificate" : "Certificado PKCS #12",
    "PEM Certificate" : "Certificado PEM",
    "Certificate" : "Certificado",
    "Private key (optional)" : "Clave privada (opcional)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La clave privada solo es necesaria si tienes la intención de enviar correos electrónicos firmados y cifrados usando este certificado.",
    "Submit" : "Enviar",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "El certificado PKCS #12 proporcionado debe contener al menos un certificado y exactamente una clave privada.",
    "Failed to import the certificate. Please check the password." : "Error al importar el certificado. Por favor, verifica la contraseña.",
    "Certificate imported successfully" : "Certificado importado con éxito",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Error al importar el certificado. Por favor, asegúrate de que la clave privada coincida con el certificado y no esté protegida por una contraseña.",
    "Failed to import the certificate" : "Error al importar el certificado",
    "Account connected" : "Cuenta conectada",
    "You can close this window" : "Puedes cerrar esta ventana",
    "Connect your mail account" : "Conecta tu cuenta de correo",
    "To add a mail account, please contact your administrator." : "Para agregar una cuenta de correo, contacta a tu administrador.",
    "All" : "Todos",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "Priority inbox" : "Bandeja de entrada prioritaria",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "Connect OAUTH2 account" : "Conectar cuenta OAUTH2",
    "Error while sharing file" : "Error al compartir el archivo",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n mensaje nuevo \nde {from}","%n mensajes nuevos \nde {from}","%n mensajes nuevos \nde {from}"],
    "Nextcloud Mail" : "Correo Nextcloud",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Ya hay un mensaje en progreso. ¡Todos los cambios no guardados se perderán si continúas!",
    "Discard changes" : "Descartar cambios",
    "Discard unsaved changes" : "Descartar cambios no guardados",
    "Keep editing message" : "Seguir editando mensaje",
    "Attachments were not copied. Please add them manually." : "No se copiaron los adjuntos. Por favor, agrégales manualmente.",
    "Message sent" : "Mensaje enviado",
    "Could not send message" : "No se pudo enviar el mensaje",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No fue posible cargar tu mensaje",
    "Could not load the desired message" : "No fue posible cargar el mensaje deseado",
    "Could not load the message" : "No fue posible cargar el mensaje",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "La liga lleva a %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
    "Continue to %s" : "Continuar a %s",
    "Unselect" : "Deseleccionar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
